@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 import pytest
 
-from patchwork.contrib.fastapi.jwt import JWTToken
-from patchwork.contrib.fastapi.settings import JWTConfig
+from patchwork.contrib.fastapi import JWTToken
+from patchwork.contrib.fastapi import JWTConfig
 
 
 @pytest.mark.asyncio
